@@ -18,12 +18,12 @@ console = get_rich_console()
 app = typer.Typer(no_args_is_help=True)
 
 
-@app.callback(invoke_without_command=True)
-def _command(
+# @app.callback(invoke_without_command=True)
+@app.command('role')
+def _role_command(
     patterns: Optional[List[str]] = typer.Option(None, "--pattern", '-p', show_default=False, help='UNIX pattern matching for generated parameters. Should be quoted. e.g. (-p "*prod-*")'),
-
 ):
-    available_services = balcony.get_available_service_node_names()
+    # available_services = balcony.get_available_service_node_names()
     balcony = BalconyAWS()
     iam_service = balcony.get_service('iam')
 
